← Back to team overview

openlp-core team mailing list archive

[Merge] lp:~meths/openlp/trivialfixes into lp:openlp

 

Jon Tibble has proposed merging lp:~meths/openlp/trivialfixes into lp:openlp.

    Requested reviews:
    OpenLP Core (openlp-core)


Cleanups all over:
- Fix multiple videos not appearing so only getting sound without image
- Import, whitespace and SPG fixes
- Include missing item from theme cleaning
- Refactor theme loading to miss large function call chain and better name and document text file loading function
- Move file test out of try as it doesn't require it
-- 
https://code.launchpad.net/~meths/openlp/trivialfixes/+merge/14853
Your team OpenLP Core is subscribed to branch lp:openlp.
=== modified file 'openlp/core/lib/__init__.py'
--- openlp/core/lib/__init__.py	2009-11-08 14:16:02 +0000
+++ openlp/core/lib/__init__.py	2009-11-14 01:05:22 +0000
@@ -27,6 +27,7 @@
 OpenLP work.
 """
 import logging
+import os.path
 import types
 
 from PyQt4 import QtCore, QtGui
@@ -49,26 +50,28 @@
     return QtGui.QApplication.translate(
         context, text, None, QtGui.QApplication.UnicodeUTF8)
 
-def file_to_xml(xmlfile):
+def get_text_file_string(text_file):
     """
-    Open a file and return the contents of the file.
+    Open a file and return the contents of the file.  If the supplied file name
+    is not a file then the function returns False.  If there is an error
+    loading the file then the function will return None.
 
-    ``xmlfile``
+    ``textfile``
         The name of the file.
     """
-    file = None
-    xml = None
+    if not os.path.isfile(text_file):
+        return False
+    file_handle = None
+    content_string = None
     try:
-        file = open(xmlfile, u'r')
-        xml = file.read()
+        file_handle = open(text_file, u'r')
+        content_string = file_handle.read()
     except IOError:
-        #This may not be an error as this is also used to check
-        #that a file exist
-        log.error(u'Failed to open XML file %s' % xmlfile)
+        log.error(u'Failed to open text file %s' % text_file)
     finally:
-        if file:
-            file.close()
-    return xml
+        if file_handle:
+            file_handle.close()
+    return content_string
 
 def str_to_bool(stringvalue):
     """
@@ -152,5 +155,5 @@
 from mediamanageritem import MediaManagerItem
 from baselistwithdnd import BaseListWithDnD
 
-__all__ = [ 'translate', 'file_to_xml', 'str_to_bool',
-            'contextMenuAction', 'contextMenuSeparator','ServiceItem']
+__all__ = [ 'translate', 'get_text_file_string', 'str_to_bool',
+            'contextMenuAction', 'contextMenuSeparator', 'ServiceItem']

=== modified file 'openlp/core/ui/amendthemeform.py'
--- openlp/core/ui/amendthemeform.py	2009-11-12 00:49:55 +0000
+++ openlp/core/ui/amendthemeform.py	2009-11-14 01:05:22 +0000
@@ -184,7 +184,7 @@
 
     def loadTheme(self, theme):
         log.debug(u'LoadTheme %s', theme)
-        self.theme = self.thememanager.getThemeData(theme)
+        self.theme = theme
         # Stop the initial screen setup generating 1 preview per field!
         self.allowPreview = False
         self.paintUi(self.theme)

=== modified file 'openlp/core/ui/maindisplay.py'
--- openlp/core/ui/maindisplay.py	2009-11-12 19:12:13 +0000
+++ openlp/core/ui/maindisplay.py	2009-11-14 01:05:22 +0000
@@ -24,7 +24,6 @@
 
 import logging
 import os
-import time
 
 from PyQt4 import QtCore, QtGui
 from PyQt4.phonon import Phonon
@@ -279,6 +278,7 @@
         self.mediaLoaded = True
         self.display.hide()
         self.video.setFullScreen(True)
+        self.video.setVisible(True)
         self.mediaObject.play()
         if self.primary:
             self.setVisible(True)
@@ -290,7 +290,6 @@
     def onMediaStop(self):
         log.debug(u'Media stopped by user')
         self.mediaObject.stop()
-        self.display.show()
 
     def onMediaFinish(self):
         log.debug(u'Reached end of media playlist')

=== modified file 'openlp/core/ui/servicemanager.py'
--- openlp/core/ui/servicemanager.py	2009-11-11 19:10:38 +0000
+++ openlp/core/ui/servicemanager.py	2009-11-14 01:05:22 +0000
@@ -23,7 +23,6 @@
 ###############################################################################
 
 import os
-import string
 import logging
 import cPickle
 import zipfile
@@ -460,7 +459,7 @@
     def onQuickSaveService(self):
         self.onSaveService(True)
 
-    def onLoadService(self, lastService = False):
+    def onLoadService(self, lastService=False):
         """
         Load an existing service from disk and rebuild the serviceitems.  All
         files retrieved from the zip file are placed in a temporary directory
@@ -481,11 +480,8 @@
             try:
                 zip = zipfile.ZipFile(unicode(filename))
                 for file in zip.namelist():
-                    if os.name == u'nt':
-                        winfile = string.replace(file, '/', os.path.sep)
-                        names = winfile.split(os.path.sep)
-                    else:
-                        names = file.split(os.path.sep)
+                    osfile = unicode(QtCore.QDir.toNativeSeparators(file))
+                    names = osfile.split(os.path.sep)
                     file_to = os.path.join(self.servicePath,
                         names[len(names) - 1])
                     f = open(file_to, u'wb')
@@ -501,7 +497,7 @@
                 for item in items:
                     serviceitem = ServiceItem()
                     serviceitem.RenderManager = self.parent.RenderManager
-                    serviceitem.set_from_service(item, self.servicePath )
+                    serviceitem.set_from_service(item, self.servicePath)
                     self.addServiceItem(serviceitem)
                 try:
                     if os.path.isfile(p_file):

=== modified file 'openlp/core/ui/slidecontroller.py'
--- openlp/core/ui/slidecontroller.py	2009-11-12 17:21:15 +0000
+++ openlp/core/ui/slidecontroller.py	2009-11-14 01:05:22 +0000
@@ -28,8 +28,7 @@
 from PyQt4 import QtCore, QtGui
 from PyQt4.phonon import Phonon
 
-from openlp.core.lib import OpenLPToolbar, Receiver, ServiceItemType, \
-    str_to_bool, PluginConfig
+from openlp.core.lib import OpenLPToolbar, Receiver, str_to_bool, PluginConfig
 
 class SlideList(QtGui.QTableWidget):
     """
@@ -424,7 +423,7 @@
     def addServiceManagerItem(self, item, slideno):
         """
         Method to install the service item into the controller and
-        request the correct the toolbar of the plugin
+        request the correct toolbar for the plugin.
         Called by ServiceManager
         """
         log.debug(u'addServiceManagerItem')

=== modified file 'openlp/core/ui/thememanager.py'
--- openlp/core/utils/registry.py	2009-11-07 00:00:36 +0000
+++ openlp/core/utils/registry.py	2009-11-14 01:05:22 +0000
@@ -101,10 +101,10 @@
             return False
 
     def _load(self):
+        if not os.path.isfile(self.file_name):
+            return False
         file_handle = None
         try:
-            if not os.path.isfile(self.file_name):
-                return False
             file_handle = open(self.file_name, u'r')
             self.config.readfp(file_handle)
             return True


Follow ups
--- openlp/core/ui/thememanager.py	2009-11-08 13:56:25 +0000
+++ openlp/core/ui/thememanager.py	2009-11-14 01:05:22 +0000
@@ -33,7 +33,7 @@
 from openlp.core.ui import AmendThemeForm
 from openlp.core.theme import Theme
 from openlp.core.lib import PluginConfig, OpenLPToolbar, ThemeXML, \
     str_to_bool, file_to_xml, buildIcon, Receiver, contextMenuAction, \
     contextMenuSeparator
 from openlp.core.utils import ConfigHelper
 
@@ -150,15 +150,17 @@
                 self.pushThemes()
 
     def onAddTheme(self):
-        self.amendThemeForm.loadTheme(None)
+        theme = self.createThemeFromXml(self.baseTheme(), self.path)
+        self.amendThemeForm.loadTheme(theme)
         self.saveThemeName = u''
         self.amendThemeForm.exec_()
 
     def onEditTheme(self):
         item = self.ThemeListWidget.currentItem()
         if item:
-            self.amendThemeForm.loadTheme(
+            theme = self.getThemeData(
                 unicode(item.data(QtCore.Qt.UserRole).toString()))
+            self.amendThemeForm.loadTheme(theme)
             self.saveThemeName = unicode(
                 item.data(QtCore.Qt.UserRole).toString())
             self.amendThemeForm.exec_()
@@ -265,7 +267,7 @@
         self.pushThemes()
 
     def pushThemes(self):
-        Receiver().send_message(u'update_themes', self.getThemes() )
+        Receiver().send_message(u'update_themes', self.getThemes())
 
     def getThemes(self):
         return self.themelist
@@ -274,7 +276,7 @@
         log.debug(u'getthemedata for theme %s', themename)
         xml_file = os.path.join(self.path, unicode(themename),
             unicode(themename) + u'.xml')
-        xml = file_to_xml(xml_file)
+        xml = get_text_file_string(xml_file)
         if not xml:
             xml = self.baseTheme()
         return self.createThemeFromXml(xml, self.path)
@@ -501,6 +503,8 @@
         theme.display_wrapStyle = theme.display_wrapStyle.strip()
         theme.font_footer_color = theme.font_footer_color.strip()
         theme.font_footer_height = int(theme.font_footer_height.strip())
+        theme.font_footer_indentation = \
+            int(theme.font_footer_indentation.strip())
         theme.font_footer_italics = str_to_bool(theme.font_footer_italics)
         theme.font_footer_name = theme.font_footer_name.strip()
         #theme.font_footer_override
@@ -33,7 +33,7 @@
 from openlp.core.theme import Theme
 from openlp.core.lib import PluginConfig, OpenLPToolbar, ThemeXML, \
-    str_to_bool, file_to_xml, buildIcon, Receiver, contextMenuAction, \
+    str_to_bool, get_text_file_string, buildIcon, Receiver, contextMenuAction, \
     contextMenuSeparator
 from openlp.core.utils import ConfigHelper

=== modified file 'openlp/core/utils/registry.py'